@@ -232,13 +232,22 @@ fn set_vcs_expires_time(config: &mut dyn Vcs, expires_in: Duration) -> Result<()
         .set_i64(CONFIG_KEY_EXPIRES, expiry_time)
         .wrap_err("failed to update the expiry time mit-relates-to")
 }
-
-#[derive(Error, Debug)]
+use miette::Diagnostic;
+#[derive(Error, Debug, Diagnostic)]
 pub enum Error {
     #[error("failed to interact with the git config: {0}")]
+    #[diagnostic(transparent)]
     GitIo(external::Error),
     #[error("failed converted epoch int between types: {0}")]
+    #[diagnostic(
+        url(docsrs),
+        code(mit_commit_message_lints::relates::vcs::error::epoch_convert)
+    )]
     EpochConvert(num::TryFromIntError),
     #[error("failed to get system time: {0}")]
+    #[diagnostic(
+        url(docsrs),
+        code(mit_commit_message_lints::relates::vcs::error::system_time)
+    )]
     SystemTime(time::SystemTimeError),
 }
